==> Patchouli-1.20.1-84.1-FABRIC-20251018.172419-2-sources.jar: vazkii/patchouli/fabric/client/FabricClientInitializer.java <==
package vazkii.patchouli.fabric.client;

import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
import net.fabricmc.fabric.api.client.model.loading.v1.ModelLoadingPlugin;
import net.fabricmc.fabric.api.client.model.loading.v1.ModelModifier;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.fabricmc.fabric.api.client.rendering.v1.HudRenderCallback;
import net.fabricmc.fabric.api.event.player.UseBlockCallback;
import net.fabricmc.fabric.api.resource.IdentifiableResourceReloadListener;
import net.fabricmc.fabric.api.resource.ResourceManagerHelper;
import net.fabricmc.fabric.api.resource.SimpleSynchronousResourceReloadListener;
import net.minecraft.class_1087;
import net.minecraft.class_1091;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3264;
import net.minecraft.class_3300;
import net.minecraft.class_3695;
import net.minecraft.class_5272;
import vazkii.patchouli.api.PatchouliAPI;
import vazkii.patchouli.client.base.BookModel;
import vazkii.patchouli.client.base.ClientTicker;
import vazkii.patchouli.client.base.PersistentData;
import vazkii.patchouli.client.book.BookContentResourceListenerLoader;
import vazkii.patchouli.client.book.ClientBookRegistry;
import vazkii.patchouli.client.handler.BookRightClickHandler;
import vazkii.patchouli.client.handler.MultiblockVisualizationHandler;
import vazkii.patchouli.common.book.Book;
import vazkii.patchouli.common.book.BookRegistry;
import vazkii.patchouli.common.item.ItemModBook;
import vazkii.patchouli.common.item.PatchouliItems;
import vazkii.patchouli.fabric.network.FabricMessageOpenBookGui;
import vazkii.patchouli.fabric.network.FabricMessageReloadBookContents;

import org.jetbrains.annotations.Nullable;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Executor;

public class FabricClientInitializer implements ClientModInitializer {
	@Override
	public void onInitializeClient() {
		ClientBookRegistry.INSTANCE.init();
		PersistentData.setup();
		ClientTickEvents.END_CLIENT_TICK.register(ClientTicker::endClientTick);
		HudRenderCallback.EVENT.register(BookRightClickHandler::onRenderHUD);
		UseBlockCallback.EVENT.register(BookRightClickHandler::onRightClick);
		UseBlockCallback.EVENT.register(MultiblockVisualizationHandler::onPlayerInteract);
		ClientTickEvents.END_CLIENT_TICK.register(MultiblockVisualizationHandler::onClientTick);
		HudRenderCallback.EVENT.register(MultiblockVisualizationHandler::onRenderHUD);
		ClientPlayNetworking.registerGlobalReceiver(FabricMessageOpenBookGui.ID, FabricMessageOpenBookGui::handle);
		ClientPlayNetworking.registerGlobalReceiver(FabricMessageReloadBookContents.ID, FabricMessageReloadBookContents::handle);

		ModelLoadingPlugin.register(pluginContext -> {
			for (Book book : BookRegistry.INSTANCE.books.values()) {
				pluginContext.addModels(new class_1091(book.model, "inventory"));
			}

			pluginContext.modifyModelAfterBake().register(
					(@Nullable class_1087 oldModel, ModelModifier.AfterBake.Context ctx) -> {
						if (ctx.id() instanceof class_1091 key
								&& PatchouliItems.BOOK_ID.equals(key) // checks namespace and path
								&& key.method_4740().equals("inventory")
								&& oldModel != null) {
							return new BookModel(oldModel, ctx.loader());
						}
						return oldModel;
					}
			);
		});

		class_5272.method_27879(PatchouliItems.BOOK,
				new class_2960(PatchouliAPI.MOD_ID, "completion"),
				(stack, world, entity, seed) -> ItemModBook.getCompletion(stack));

		ResourceManagerHelper.get(class_3264.field_14188).registerReloadListener(new IdentifiableResourceReloadListener() {
			private static final class_2960 id = new class_2960(PatchouliAPI.MOD_ID, "resource_pack_books");

			@Override
			public CompletableFuture<Void> method_25931(class_4045 barrier, class_3300 manager, class_3695 preparationsProfiler, class_3695 reloadProfiler, Executor backgroundExecutor, Executor gameExecutor) {
				return BookContentResourceListenerLoader.INSTANCE.method_25931(barrier, manager, preparationsProfiler, reloadProfiler, backgroundExecutor, gameExecutor);
			}

			@Override
			public class_2960 getFabricId() {
				return id;
			}
		});
		ResourceManagerHelper.get(class_3264.field_14188).registerReloadListener(new SimpleSynchronousResourceReloadListener() {
			private static final class_2960 id = new class_2960(PatchouliAPI.MOD_ID, "reload_hook");

			@Override
			public class_2960 getFabricId() {
				return id;
			}

			@Override
			public void method_14491(class_3300 manager) {
				if (class_310.method_1551().field_1687 != null) {
					PatchouliAPI.LOGGER.info("Reloading resource pack-based books");
					ClientBookRegistry.INSTANCE.reload();
				} else {
					PatchouliAPI.LOGGER.debug("Not reloading resource pack-based books as client world is missing");
				}
			}
		});
	}
}

==> Patchouli-1.21.1-91-FABRIC-20250802.172951-1-sources.jar: vazkii/patchouli/fabric/client/FabricClientInitializer.java <==
package vazkii.patchouli.fabric.client;

import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
import net.fabricmc.fabric.api.client.model.loading.v1.ModelLoadingPlugin;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.fabricmc.fabric.api.client.rendering.v1.HudRenderCallback;
import net.fabricmc.fabric.api.event.player.UseBlockCallback;
import net.fabricmc.fabric.api.resource.IdentifiableResourceReloadListener;
import net.fabricmc.fabric.api.resource.ResourceManagerHelper;
import net.fabricmc.fabric.api.resource.SimpleSynchronousResourceReloadListener;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3264;
import net.minecraft.class_3300;
import net.minecraft.class_3695;
import net.minecraft.class_5272;
import vazkii.patchouli.api.PatchouliAPI;
import vazkii.patchouli.client.base.BookModel;
import vazkii.patchouli.client.base.ClientTicker;
import vazkii.patchouli.client.base.PersistentData;
import vazkii.patchouli.client.book.BookContentResourceListenerLoader;
import vazkii.patchouli.client.book.ClientBookRegistry;
import vazkii.patchouli.client.handler.BookRightClickHandler;
import vazkii.patchouli.client.handler.MultiblockVisualizationHandler;
import vazkii.patchouli.common.book.Book;
import vazkii.patchouli.common.book.BookRegistry;
import vazkii.patchouli.common.item.ItemModBook;
import vazkii.patchouli.common.item.PatchouliItems;
import vazkii.patchouli.fabric.network.FabricMessageOpenBookGui;
import vazkii.patchouli.fabric.network.FabricMessageReloadBookContents;
import vazkii.patchouli.network.MessageOpenBookGui;
import vazkii.patchouli.network.MessageReloadBookContents;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Executor;

public class FabricClientInitializer implements ClientModInitializer {
	@Override
	public void onInitializeClient() {
		ClientBookRegistry.INSTANCE.init();
		PersistentData.setup();
		ClientTickEvents.END_CLIENT_TICK.register(ClientTicker::endClientTick);
		HudRenderCallback.EVENT.register(BookRightClickHandler::onRenderHUD);
		UseBlockCallback.EVENT.register(BookRightClickHandler::onRightClick);
		UseBlockCallback.EVENT.register(MultiblockVisualizationHandler::onPlayerInteract);
		ClientTickEvents.END_CLIENT_TICK.register(MultiblockVisualizationHandler::onClientTick);
		HudRenderCallback.EVENT.register(MultiblockVisualizationHandler::onRenderHUD);
		ClientPlayNetworking.registerGlobalReceiver(MessageOpenBookGui.TYPE, FabricMessageOpenBookGui::handle);
		ClientPlayNetworking.registerGlobalReceiver(MessageReloadBookContents.TYPE, FabricMessageReloadBookContents::handle);

		ModelLoadingPlugin.register(pluginContext -> {
			for (Book book : BookRegistry.INSTANCE.books.values()) {
				PatchouliAPI.LOGGER.info("Adding model {}", book.model);
				pluginContext.addModels(book.model);
			}

			pluginContext.modifyModelAfterBake().register(
					(oldModel, ctx) -> {
						if (ctx.topLevelId() != null &&
								PatchouliItems.BOOK_ID.equals(ctx.topLevelId().comp_2875()) // checks namespace and path
								&& ctx.topLevelId().method_4740().equals("inventory")
								&& oldModel != null) {
							return new BookModel(oldModel, (model) -> class_310.method_1551().method_1554().getModel(model));
						}
						return oldModel;
					}
			);
		});

		class_5272.method_27879(PatchouliItems.BOOK,
				class_2960.method_60655(PatchouliAPI.MOD_ID, "completion"),
				(stack, world, entity, seed) -> ItemModBook.getCompletion(stack));

		ResourceManagerHelper.get(class_3264.field_14188).registerReloadListener(new IdentifiableResourceReloadListener() {
			private static final class_2960 id = class_2960.method_60655(PatchouliAPI.MOD_ID, "resource_pack_books");

			@Override
			public CompletableFuture<Void> method_25931(class_4045 barrier, class_3300 manager, class_3695 preparationsProfiler, class_3695 reloadProfiler, Executor backgroundExecutor, Executor gameExecutor) {
				return BookContentResourceListenerLoader.INSTANCE.method_25931(barrier, manager, preparationsProfiler, reloadProfiler, backgroundExecutor, gameExecutor);
			}

			@Override
			public class_2960 getFabricId() {
				return id;
			}
		});
		ResourceManagerHelper.get(class_3264.field_14188).registerReloadListener(new SimpleSynchronousResourceReloadListener() {
			private static final class_2960 id = class_2960.method_60655(PatchouliAPI.MOD_ID, "reload_hook");

			@Override
			public class_2960 getFabricId() {
				return id;
			}

			@Override
			public void method_14491(class_3300 manager) {
				if (class_310.method_1551().field_1687 != null) {
					PatchouliAPI.LOGGER.info("Reloading resource pack-based books");
					ClientBookRegistry.INSTANCE.reload();
				} else {
					PatchouliAPI.LOGGER.debug("Not reloading resource pack-based books as client world is missing");
				}
			}
		});
	}
}
